# Changelog

## 2.0.0

- Require polliwog 3.0.0 prerelease or higher, and update rtree.


## 1.1.1

- Support polliwog 3.0.0 prereleases.


## 1.1.0

- Upgrade polliwog dependency.


## 1.0.0

- Upgrade polliwog and vg dependencies.


## 0.4.0

- Upgrade polliwog and vg dependencies.


## 0.3.0

- Upgrade polliwog dependency.


## 0.3.0b0

Same as 0.2.0b0.


## 0.2.0b0

- Bump rtree to 0.9.7, which now ships wheels with libspatialindex
  preinstalled. It's no longer necessary to separately install libspatialindex.


## 0.2.0

- Bump polliwog to 1.0.0b10.


## 0.1.0

Initial release.
